@@ -15,8 +15,16 @@
 
 #ifdef WIN32
 #include <windows.h>  /* needed by Windows' gl.h etc */
+#include "SDL.h"
+#include "SDL_byteorder.h"
+#include "SDL_events.h"
+#include "SDL_syswm.h"
+#else
+#include "SDL/SDL.h"
+#include "SDL/SDL_byteorder.h"
+#include "SDL/SDL_events.h"
+#include "SDL/SDL_syswm.h"
 #endif
-#include <SDL.h>
 
 #include "esdl_conv.h"
 
@@ -60,7 +68,7 @@ char* sdl_get_temp_buff(sdl_data*, int);
 void sdl_free_binaries(sdl_data*);
 
 void init_fps(sdl_data*);
-void gl_dispatch(sdl_data *, int, int, char *);
+void gl_dispatch(sdl_data *, int, ErlDrvSizeT, char *);
 void es_init_opengl(sdl_data *, int, char *);
 void start_opengl_thread(sdl_data *);
 void stop_opengl_thread();
